from setuptools import setup, find_packages

setup(
    name="ai_platform_iscas",
    version="0.1",
    author="vicmeng",
    author_email="1137998920@qq.com",
    description="A brief description of your package",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)